@@ -62,15 +62,16 @@ class DataFrameSummary(object):
         raise KeyError(column)
     @classmethod
     def _get_pairplot(self,data=None,continuous=[],categorical=[]):
+        self.data=data
         print("Hello!",continuous)
-        if(data==None):
+        if(self.data==None):
             return "Send the Data Please"
-        for i in data.columns:
-            if(data[i].nunique/data.shape[0])*100>20:
+        for i in self.data.columns:
+            if(self.data[i].nunique/data.shape[0])*100>20:
                continuous.append(i)
             else:
                categorical.append(i)
-        cn=data.drop(columns=categorical,axis=1)
+        cn=self.data.drop(columns=categorical,axis=1)
         return sn.pairplot(cn,corner=True,kind="scatter")
         
         
